@@ -7,11 +7,11 @@ from .errors import CaptureError
 import logging
 
 import numpy as np
-from joule.utils.time import (timestamp_to_human,
-                              seconds_to_timestamp, now as time_now)
+from joule.utilities import (timestamp_to_human,
+                              seconds_to_timestamp, time_now)
 
 ROW_BYTES = 8 * 2 + 2 + 2  # 8 channels, 2 byte alignment, 2 byte status
-ROWS_PER_BLOCK = 1000  # read ~3 blocks per second
+ROWS_PER_BLOCK = 3000  # read ~3 blocks per second
 BLOCK_SIZE = ROW_BYTES * ROWS_PER_BLOCK
 
 
@@ -57,6 +57,7 @@ class SerialCapture():
                 self.clock_ts = time_now()
                 self.data_ts = self.clock_ts
             sys.stderr.flush()
+        await output.close()
 
     def stop(self):
         self.stop_requested = True
